@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
   based on code from kopete
 
   This library is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 #include <KActionMenu>
 
 namespace KPIMTextEdit {
-class KPIMTEXTEDIT_EXPORT EmoticonTextEditAction : public KActionMenu
+class EmoticonTextEditAction : public KActionMenu
 {
     Q_OBJECT
 public:
